<?php
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
declare(strict_types=1);

namespace Threepartment\Serialnumbers\Observer;

use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\Event\Observer as EventObserver;

/**
 * Class AssignSerialNumbers
 */
class AssignSerialNumbers implements ObserverInterface
{

    /**
     * @var  \Magento\Framework\App\ResourceConnection
     */
    protected $resource;

    /**
     * @var \Magento\Framework\App\RequestInterface
     */
    protected $request;
    /**
     * @param IsSingleSourceModeInterface $isSingleSourceMode
     * @param DefaultSourceProviderInterface $defaultSourceProvider
     * @param GetItemsToDeductFromShipment $getItemsToDeductFromShipment
     * @param SourceDeductionRequestFromShipmentFactory $sourceDeductionRequestFromShipmentFactory
     * @param SourceDeductionServiceInterface $sourceDeductionService
     * @param ItemToSellInterfaceFactory $itemsToSellFactory
     * @param PlaceReservationsForSalesEventInterface $placeReservationsForSalesEvent
     */
    public function __construct(

        \Magento\Framework\App\ResourceConnection $resource,
        \Magento\Framework\App\RequestInterface $request
    ) {

        $this->request = $request;
        $this->resource = $resource;
    }

    /**
     * @param EventObserver $observer
     * @return void
     */
    public function execute(EventObserver $observer){
        /** @var \Magento\Sales\Model\Order\Shipment $shipment */
        $shipment = $observer->getEvent()->getShipment();
        if ($shipment->getOrigData('entity_id')) {
            return;
        }
        $post = $this->request->getPostValue();
        $order_id = $shipment->getOrderId();
        if(isset($post['shipment']['serials'])){
            $query = "";
            $serial_ids = implode(',', $post['shipment']['serials']);
            //Update serial table
            $connection  = $this->resource->getConnection();
            $tableName   = $connection->getTableName('threepartment_serialnumbers_serialnumber');
            $query = 'UPDATE ' . $tableName. " SET order_id = $order_id, status=1, date_updated=NOW() WHERE serial_number_id IN ($serial_ids) AND `status`=0";
            $this->resource->getConnection()->query($query);
        }
    }
}
