<?php

namespace Threepartment\Serialnumbers\Ui\Component\Listing\Serialnumber\Column;

use Magento\Framework\View\Element\UiComponent\ContextInterface;
use Magento\Framework\View\Element\UiComponentFactory;
use Magento\Ui\Component\Listing\Columns\Column;
use Magento\Framework\UrlInterface;

class OrderAction extends Column
{
    /** Url path */
    const ROW_EDIT_URL = 'sales/order/view'; 
    /** @var UrlInterface */
    protected $_urlBuilder;

    /**
     * @var string
     */
    private $_editUrl;
    protected $_orderRepository;

    /**
     * @param ContextInterface   $context
     * @param UiComponentFactory $uiComponentFactory
     * @param UrlInterface       $urlBuilder
     * @param array              $components
     * @param array              $data
     * @param string             $editUrl
     */
    public function __construct(
        ContextInterface $context,
        UiComponentFactory $uiComponentFactory,
        UrlInterface $urlBuilder,
        array $components = [],
        array $data = [],
        \Magento\Sales\Api\OrderRepositoryInterface $orderRepository,
        $editUrl = self::ROW_EDIT_URL
    ) {
        $this->_urlBuilder = $urlBuilder;
        $this->_editUrl = $editUrl;
        $this->_orderRepository = $orderRepository;
        parent::__construct($context, $uiComponentFactory, $components, $data);
    }

    /**
     * Prepare Data Source.
     *
     * @param array $dataSource
     *
     * @return array
     */
    public function prepareDataSource(array $dataSource)
    {
        if (isset($dataSource['data']['items'])) {
            foreach ($dataSource['data']['items'] as &$item) {
                $name = $this->getData('name');
                if (isset($item['order_id'])) {
                    $the_order = $this->_orderRepository->get($item['order_id']);

                    $item[$name]['order_url'] = [
                        'href' => $this->_urlBuilder->getUrl(
                            $this->_editUrl,
                            ['order_id' => $item['order_id']]
                        ),
                        'label' => $the_order->getIncrementId(),
                    ];
                }
            }
        }
        return $dataSource;
    }
}
